@@ -1,6 +1,6 @@
 /**
  * @file  cfgfile.h
- * @copyright Copyright (C) 2019 Michał Bąbik
+ * @copyright Copyright (C) 2019-2020 Michał Bąbik
  *
  * This file is part of Wall Changer.
  *
@@ -43,7 +43,7 @@
 /*----------------------------------------------------------------------------*/
 char * check_config_path_file (int *i_err);
 
-int    set_config_file_path   (char *s_path);
+int    set_config_file_path   (char *s_path) __attribute__ ((nonnull (1)));
 /*----------------------------------------------------------------------------*/
 #endif
 
