@@ -27,11 +27,11 @@
 /**
  * @brief  djb2 hash function.
  */
-uint32_t
+uint_fast32_t
 hash (const char * __restrict str)
 {
-    uint32_t hash = 5381;
-    int         c = 0;
+    uint_fast32_t hash = 5381;
+    int_fast32_t  c    = 0;
 
     while ((c = *str++)) {
 
